@@ -167,7 +167,6 @@ class RedisForeignKey(RedisNumber):
     def deserialize_value(self, value, redis_root):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
-            value = super().deserialize_value(value, redis_root)
             check_types(value, int)
             model_name = self.model.__name__
             instance_id = value
@@ -304,9 +303,6 @@ class RedisDecimal(RedisString):
         self.value = self.check_value()
         if self.value not in [None, 'null']:
             check_types(self.value, (int, float, decimal.Decimal))
-            print(self.value)
-            self.value = str(self.value)
-            print(self.value)
         return super().clean()
 
     def deserialize_value(self, value, redis_root):
@@ -1159,13 +1155,21 @@ class RedisModel:
         for field_name, field in fields.items():
             if not field_name.startswith('__'):
                 try:
-                    deserialized_fields[field_name] = field.value
-                    print(field_name, field.value, type(field.value))
+                    if isinstance(field, RedisForeignKey):
+                        id = get_ids_from_untyped_data(field.value)[0]
+                        deserialized_value = redis_root.deserialize_value(id, name, field_name)
+                    elif isinstance(field, RedisManyToMany):
+                        ids = get_ids_from_untyped_data(field.value)
+                        deserialized_value = redis_root.deserialize_value(ids, name, field_name)
+                    else:
+                        deserialized_value = redis_root.deserialize_value(field.value, name, field_name)
+                    deserialized_fields[field_name] = deserialized_value
                     cleaned_value = field.clean()
+
                     cleaned_fields[field_name] = cleaned_value
                 except BaseException as ex:
                     raise Exception(f'{ex} ({name} -> {field_name})')
-        return instance_key, deserialized_fields
+        return instance_key, cleaned_fields, deserialized_fields
     
     def get_model_ttl(self):
         ttl = None
@@ -1175,14 +1179,14 @@ class RedisModel:
         return ttl
 
     def _set_fields(self):
-        instance_key, fields_dict = self._serialize_data()
+        instance_key, fields_dict, deserialized_fields = self._serialize_data()
         model_ttl = self.get_model_ttl()
         redis_root = self.__model_data__['redis_root']
         prefix, model_name, instance_id = instance_key.split(':')
         redis_instance = redis_root.redis_instance
         fields_json = json.dumps(fields_dict)
         redis_instance.set(instance_key, fields_json, ex=model_ttl)
-        saved_instance = fields_dict
+        saved_instance = deserialized_fields
         return saved_instance
 
     def _get_new_id(self):
